==> jc-1.4.0.tar.gz: soot/grimp/internal/GAndExpr.h <==
// public class soot.grimp.internal.GAndExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 5db408cd5e821f4f soot_grimp_internal_AbstractGrimpIntLongBinopExpr
// @dep_class fb0f54422c4af12 soot_grimp_internal_GAndExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpIntLongBinopExpr

#include "soot/grimp/internal/AbstractGrimpIntLongBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GAndExpr_H_
#define _JC_soot_grimp_internal_GAndExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GAndExpr$sub_refs	_jc_soot_grimp_internal_GAndExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GAndExpr$sub_nonrefs	_jc_soot_grimp_internal_GAndExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GAndExpr$refs	_jc_soot_grimp_internal_GAndExpr$refs;
typedef struct _jc_soot_grimp_internal_GAndExpr$nonrefs	_jc_soot_grimp_internal_GAndExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GAndExpr$object	_jc_soot_grimp_internal_GAndExpr$object;

typedef const struct _jc_soot_grimp_internal_GAndExpr$vmethods	_jc_soot_grimp_internal_GAndExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GAndExpr$vtable	_jc_soot_grimp_internal_GAndExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GAndExpr$vtype	_jc_soot_grimp_internal_GAndExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GAndExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_grimp_internal_GAndExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GAndExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *);
extern jint _jc_soot_grimp_internal_GAndExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *);
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GAndExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GAndExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *);
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *);
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GAndExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
	_jc_soot_grimp_internal_GAndExpr$vmethods	soot_grimp_internal_GAndExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GAndExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GAndExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAndExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GAndExpr$refs {
    _jc_soot_grimp_internal_GAndExpr$sub_refs	soot_grimp_internal_GAndExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAndExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GAndExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_grimp_internal_GAndExpr$sub_nonrefs	soot_grimp_internal_GAndExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GAndExpr$object {
	_jc_soot_grimp_internal_GAndExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GAndExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GAndExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GAndExpr$vtype _jc_soot_grimp_internal_GAndExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GAndExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GAndExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GAndExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GAndExpr.h <==
// public class soot.grimp.internal.GAndExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 5db408cd5e821f4f soot_grimp_internal_AbstractGrimpIntLongBinopExpr
// @dep_class fb0f54422c4af12 soot_grimp_internal_GAndExpr
// @dep_class d9b18ba3bd644eaa soot_jimple_internal_AbstractBinopExpr
// @dep_class 91b80fdb10e99b48 soot_jimple_internal_AbstractIntLongBinopExpr

// header file dependencies
// @dep_header soot_grimp_internal_AbstractGrimpIntLongBinopExpr

#include "soot/grimp/internal/AbstractGrimpIntLongBinopExpr.h"

#ifndef _JC_soot_grimp_internal_GAndExpr_H_
#define _JC_soot_grimp_internal_GAndExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Value$object;
struct _jc_soot_util_Switch$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GAndExpr$sub_refs	_jc_soot_grimp_internal_GAndExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GAndExpr$sub_nonrefs	_jc_soot_grimp_internal_GAndExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GAndExpr$refs	_jc_soot_grimp_internal_GAndExpr$refs;
typedef struct _jc_soot_grimp_internal_GAndExpr$nonrefs	_jc_soot_grimp_internal_GAndExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GAndExpr$object	_jc_soot_grimp_internal_GAndExpr$object;

typedef const struct _jc_soot_grimp_internal_GAndExpr$vmethods	_jc_soot_grimp_internal_GAndExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GAndExpr$vtable	_jc_soot_grimp_internal_GAndExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GAndExpr$vtype	_jc_soot_grimp_internal_GAndExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GAndExpr$method$_init$b3c9ec81c7d0a5b0(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_grimp_internal_GAndExpr$method$apply$cd67f53165014a6d(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GAndExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_grimp_internal_GAndExpr$method$getPrecedence$9873747576c8b2e5(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_grimp_internal_GAndExpr$method$getSymbol$ce407d9fb7da8b41(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$apply$cd67f53165014a6d;
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$getPrecedence$9873747576c8b2e5;
extern _jc_method _jc_soot_grimp_internal_GAndExpr$method_info$getSymbol$ce407d9fb7da8b41;

// Virtual methods structure
struct _jc_soot_grimp_internal_GAndExpr$vmethods {
	void	(*apply$cd67f53165014a6d)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *) _JC_JCNI_ATTR;
	jint	(*getPrecedence$9873747576c8b2e5)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getSymbol$ce407d9fb7da8b41)(_jc_env *, struct _jc_soot_grimp_internal_GAndExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GAndExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractBinopExpr$vmethods	soot_jimple_internal_AbstractBinopExpr;
	_jc_soot_jimple_internal_AbstractIntLongBinopExpr$vmethods	soot_jimple_internal_AbstractIntLongBinopExpr;
	_jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$vmethods	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
	_jc_soot_grimp_internal_GAndExpr$vmethods	soot_grimp_internal_GAndExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GAndExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GAndExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAndExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GAndExpr$refs {
    _jc_soot_grimp_internal_GAndExpr$sub_refs	soot_grimp_internal_GAndExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_refs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_refs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_refs	soot_jimple_internal_AbstractBinopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GAndExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GAndExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractBinopExpr;
    _jc_soot_jimple_internal_AbstractIntLongBinopExpr$sub_nonrefs	soot_jimple_internal_AbstractIntLongBinopExpr;
    _jc_soot_grimp_internal_AbstractGrimpIntLongBinopExpr$sub_nonrefs	soot_grimp_internal_AbstractGrimpIntLongBinopExpr;
    _jc_soot_grimp_internal_GAndExpr$sub_nonrefs	soot_grimp_internal_GAndExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GAndExpr$object {
	_jc_soot_grimp_internal_GAndExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GAndExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GAndExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GAndExpr$vtype _jc_soot_grimp_internal_GAndExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GAndExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GAndExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GAndExpr_H_ */
